summaryrefslogtreecommitdiff
path: root/state.go
diff options
context:
space:
mode:
authorWolfy-J <[email protected]>2019-05-03 13:38:20 +0300
committerWolfy-J <[email protected]>2019-05-03 13:38:20 +0300
commite9d42947a6922ce2f0aa9f9bcab4ead167735bc9 (patch)
tree38f84e1b1c26d15f4815f1e4509c0fc9031e6f87 /state.go
parente52c29d081a14f0ec4efb01da11c69215ea40a6a (diff)
better status
Diffstat (limited to 'state.go')
-rw-r--r--state.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/state.go b/state.go
index a5bd4397..bf88f012 100644
--- a/state.go
+++ b/state.go
@@ -26,8 +26,8 @@ const (
// StateWorking - working on given payload.
StateWorking
- // StateDisabled - indicates that worker is being disabled and will be removed.
- StateDisabled
+ // StateInvalid - indicates that worker is being disabled and will be removed.
+ StateInvalid
// StateStopping - process is being softly stopped.
StateStopping
@@ -57,8 +57,8 @@ func (s *state) String() string {
return "ready"
case StateWorking:
return "working"
- case StateDisabled:
- return "disabled"
+ case StateInvalid:
+ return "invalid"
case StateStopped:
return "stopped"
case StateErrored: